summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2019-01-30 08:39:14 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2019-02-07 12:31:23 +0000
commit9977e8017d9094b95daf46d5f7296e412685cad1 (patch)
tree2e279f38fa52e2d651ec84ee101b2395e6596b65
parent72ac59b275e8f9beb2a8c7c0506ce507fdb788c6 (diff)
round-robin.sh: Support using ABE's internal sources in build_abe
Use ABE's internal linux sources for installation of kernel headers. This simplifies tcwg_bmk project where we don't need to track kernel sources. Change-Id: I2a8eb6978f7b8783fefb6278b601353941d06aa0
-rw-r--r--round-robin.sh32
1 files changed, 19 insertions, 13 deletions
diff --git a/round-robin.sh b/round-robin.sh
index b6196176..e4ff41a0 100644
--- a/round-robin.sh
+++ b/round-robin.sh
@@ -208,16 +208,23 @@ build_abe ()
;;
esac
- clone_repo $project
-
- # Don't use ABE's repo clone functions and setup abe/snapshots/ directory
- # to have the right entries.
- local git_dir git_path
- git_dir="$(basename ${rr[${project}_url]})"
- git_path="abe/snapshots/$git_dir"
- rm -rf $git_path $git_path~master
- ln -s $(pwd)/$project $git_path
- ln -s $(pwd)/$project $git_path~master
+ # Use our custom sources for everything, but kernel headers.
+ local custom_abe_src_opt=""
+ local git_dir="$project"
+ if [ x"$component" != x"linux" ]; then
+ clone_repo $project
+
+ # Don't use ABE's repo clone functions and setup abe/snapshots/ directory
+ # to have the right entries.
+ local git_dir git_path
+ git_dir="$(basename ${rr[${project}_url]})"
+ git_path="abe/snapshots/$git_dir"
+ rm -rf $git_path $git_path~master
+ ln -s $(pwd)/$project $git_path
+ ln -s $(pwd)/$project $git_path~master
+
+ custom_abe_src_opt="$project=${rr[${project}_url]}~master --disable update"
+ fi
cd abe
@@ -226,7 +233,7 @@ build_abe ()
# Remove previous build directories and .stamp files.
# We rely on ccache for fast rebuilds.
- set +f; rm -rf builds/x86_64-unknown-linux-gnu/$gnu_target/$git_dir~master*; set -f
+ set +f; rm -rf builds/*/*/$git_dir*; set -f
export PATH=$(pwd)/bin:$PATH
@@ -245,8 +252,7 @@ build_abe ()
--build $project \
--target $gnu_target \
--extraconfigdir config/master \
- --disable update \
- $project=${rr[${project}_url]}~master \
+ $custom_abe_src_opt \
$stage
ccache -s
)